@@ -13,6 +13,7 @@ from ._docker import _AlwaysContains, _is_docker
 from ._email import ConsoleEmailMixin, SmtpEmailMixin
 from ._extensions import ExtensionsMixin
 from ._filter import FilterMixin
+from ._girder_utils import GirderUtilsMixin
 from ._https import HttpsMixin
 from ._logging import LoggingMixin
 from ._rest_framework import RestFrameworkMixin
@@ -23,6 +24,7 @@ from ._storage import MinioStorageMixin, S3StorageMixin
 
 # Subclasses are loaded in last to first ordering
 class _BaseConfiguration(
+    GirderUtilsMixin,
     ExtensionsMixin,
     CeleryMixin,
     RestFrameworkMixin,
@@ -101,6 +103,14 @@ class _HerokuMixin:
     )
     # https://help.heroku.com/J2R1S4T8/can-heroku-force-an-application-to-use-ssl-tls
     SECURE_PROXY_SSL_HEADER: Optional[Tuple[str, str]] = ('HTTP_X_FORWARDED_PROTO', 'https')
+    # This may be provided by https://github.com/ianpurvis/heroku-buildpack-version or similar
+    # The commit SHA is the preferred release tag for Git-based projects:
+    # https://docs.sentry.io/platforms/python/configuration/releases/#bind-the-version
+    SENTRY_RELEASE = values.Value(
+        None,
+        environ_name='SOURCE_VERSION',
+        environ_prefix=None,
+    )
 
 
 class HerokuProductionBaseConfiguration(_HerokuMixin, ProductionBaseConfiguration):
